from importlib import metadata

# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "IDAES Flowsheet Processor"
copyright = "2024, WaterTAP"
author = "WaterTAP"

release = version = metadata.version("idaes-flowsheet-processor")

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    "sphinx_rtd_theme",
    "sphinx.ext.doctest",
    "sphinx.ext.napoleon",
    "autoapi.extension",
    "sphinx.ext.intersphinx",
]
suppress_warnings = []

templates_path = ["_templates"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# see https://sphinx-autoapi.readthedocs.io/en/latest/reference/config.html
autoapi_dirs = ["../src"]
autoapi_root = "technical_reference"
autoapi_options = [
    "members",
    "undoc-members",
    "show-module-summary",
]
# set to True to save the autogenerated
autoapi_keep_files = False
autoapi_ignore = ["*conftest.py", "*test_*.py", "*tests/*.py", "*_testing/*.py"]
# suppress_warnings += ["autoapi.python_import_resolution"]

intersphinx_mapping = {
    "python": ("https://docs.python.org/3", None),
    "pyomo": ("https://pyomo.readthedocs.io/en/stable", None),
    "numpy": ("https://numpy.org/doc/stable", None),
    "idaes": ("https://idaes-pse.readthedocs.io/en/stable", None),
    "watertap": ("https://watertap.readthedocs.io/en/latest", None),
    "prommis": ("https://prommis.readthedocs.io/en/latest", None),
}


def _skip_tests(app, what: str, name: str, obj, skip, options):
    return skip


def setup(sphinx):
    sphinx.connect("autoapi-skip-member", _skip_tests)


# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "sphinx_rtd_theme"
html_static_path = []
